==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation type="unfinished">Yok</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation type="unfinished">Kapat</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Yok</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-globalkeys/lxqt-config-globalkeyshortcuts/lxqt-config-globalkeyshortcuts_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>DefaultModel</name>
    <message>
        <location filename="../../../default_model.cpp" line="49"/>
        <source>Command</source>
        <translation>Komut</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="50"/>
        <source>DBus call</source>
        <translation>DBus çağrısı</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="51"/>
        <source>Client</source>
        <translation>İstemci</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="141"/>
        <source>Id</source>
        <translation>Id</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="144"/>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="147"/>
        <source>Description</source>
        <translation>Açıklama</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="150"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../../../default_model.cpp" line="153"/>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
</context>
<context>
    <name>EditActionDialog</name>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="14"/>
        <source>Edit Action</source>
        <translation>Eylemi Düzenle</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="31"/>
        <source>&amp;Shortcut:</source>
        <translation>&amp;Kısayol:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="74"/>
        <source>&amp;Description:</source>
        <translation>&amp;Açıklama:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="87"/>
        <source>&amp;Enabled</source>
        <translation>&amp;Etkinleştir</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="102"/>
        <source>&amp;Command</source>
        <translation>&amp;Komut</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="109"/>
        <source>&amp;DBus message</source>
        <translation>&amp;DBus iletisi</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="118"/>
        <source>Type:</source>
        <translation>Tür:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="164"/>
        <source>Co&amp;mmand:</source>
        <translation>&amp;Komut:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="206"/>
        <source>S&amp;ervice:</source>
        <translation>S&amp;evis:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="219"/>
        <source>&amp;Path:</source>
        <translation>&amp;Yol:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="232"/>
        <source>&amp;Interface:</source>
        <translation>&amp;Arayüz:</translation>
    </message>
    <message>
        <location filename="../../../edit_action_dialog.ui" line="245"/>
        <source>&amp;Method:</source>
        <translation>&amp;Yöntem:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../main_window.ui" line="14"/>
        <source>Global Actions Manager</source>
        <translation>Küresel Eylemler Yöneticisi</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="52"/>
        <source>Add ...</source>
        <translation>Ekle...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="62"/>
        <source>Remove</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="72"/>
        <source>Modify ...</source>
        <translation>Düzenle ...</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="89"/>
        <source>Swap</source>
        <translation>Değiştir</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="115"/>
        <source>Multiple actions behaviour:</source>
        <translation>Çoklu eylem davranışı:</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="123"/>
        <source>First</source>
        <translation>Birinci</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="128"/>
        <source>Last</source>
        <translation>Sonuncu</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="133"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="138"/>
        <source>All</source>
        <translation>Hepsi</translation>
    </message>
    <message>
        <location filename="../../../main_window.ui" line="176"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>ShortcutConfigWindow</name>
    <message>
        <source>Close</source>
        <translation type="vanished">Kapat</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>None</source>
        <translation type="vanished">Yok</translation>
    </message>
</context>
</TS>
